%global testsuite_ver ff37e2
%global clknetsim_ver 9ed48d
%global selinuxtype targeted

Summary:	PTP implementation for Linux
Name:		linuxptp
Version:	3.1.1
Release:	4%{?dist}
License:	GPLv2+
URL:		http://linuxptp.sourceforge.net/

Source0:	https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tgz
Source1:	phc2sys.service
Source2:	ptp4l.service
Source3:	timemaster.service
Source4:	timemaster.conf
Source5:	ptp4l.conf
Source6:	https://github.com/mlichvar/linuxptp-testsuite/archive/%{testsuite_ver}/linuxptp-testsuite-%{testsuite_ver}.tar.gz
Source7:	https://github.com/mlichvar/clknetsim/archive/%{clknetsim_ver}/clknetsim-%{clknetsim_ver}.tar.gz
Source8:	linuxptp.fc
Source9:	linuxptp.if
Source10:	linuxptp.te

Patch3000:	linuxptp-zerolength.patch
Patch3001:      clknetsim-phc2sys.patch

BuildRequires: gcc-c++ make systemd
Requires:	(%{name}-selinux if selinux-policy-%{selinuxtype})

%{?systemd_requires}


%description
This software is an implementation of the Precision Time Protocol (PTP)
according to IEEE standard 1588 for Linux. The dual design goals are to provide
a robust implementation of the standard and to use the most relevant and modern
Application Programming Interfaces (API) offered by the Linux kernel.
Supporting legacy APIs and other platforms is not a goal.

%package selinux
Summary:	linuxptp SELinux policy
BuildArch:	noarch
BuildRequires:	selinux-policy-devel
Requires:	selinux-policy-%{selinuxtype}
Requires(post):	selinux-policy-%{selinuxtype}
%{?selinux_requires}

%description selinux
linuxptp SELinux policy module

%prep
%setup -a 6 -a 7 -q
%patch3000 -p1

mv linuxptp-testsuite-%{testsuite_ver}* testsuite
mv clknetsim-%{clknetsim_ver}* testsuite/clknetsim

pushd testsuite/clknetsim
%patch3001 -p1 -R
popd

mkdir selinux
cp -p %{SOURCE8} %{SOURCE9} %{SOURCE10} selinux

%build
%{make_build} \
	EXTRA_CFLAGS="$RPM_OPT_FLAGS" \
	EXTRA_LDFLAGS="$RPM_LD_FLAGS"

make -C selinux -f %{_datadir}/selinux/devel/Makefile linuxptp.pp
bzip2 -9 selinux/linuxptp.pp

%install
%makeinstall

mkdir -p %{buildroot}{%{_sysconfdir}/sysconfig,%{_unitdir},%{_mandir}/man5}
install -m 644 -p %{SOURCE1} %{SOURCE2} %{SOURCE3} %{buildroot}%{_unitdir}
install -m 644 -p %{SOURCE4} %{SOURCE5} %{buildroot}%{_sysconfdir}

echo 'OPTIONS="-f /etc/ptp4l.conf"' > \
	%{buildroot}%{_sysconfdir}/sysconfig/ptp4l
echo 'OPTIONS="-a -r"' > %{buildroot}%{_sysconfdir}/sysconfig/phc2sys

echo '.so man8/ptp4l.8' > %{buildroot}%{_mandir}/man5/ptp4l.conf.5
echo '.so man8/timemaster.8' > %{buildroot}%{_mandir}/man5/timemaster.conf.5

install -D -m 0644 selinux/linuxptp.pp.bz2 \
	%{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}/linuxptp.pp.bz2
install -D -p -m 0644 selinux/linuxptp.if \
	%{buildroot}%{_datadir}/selinux/devel/include/distributed/linuxptp.if

%check
cd testsuite
export CLKNETSIM_RANDOM_SEED=26743
%{make_build} -C clknetsim
PATH=..:$PATH ./run

%post
%systemd_post phc2sys.service ptp4l.service timemaster.service

%preun
%systemd_preun phc2sys.service ptp4l.service timemaster.service

%postun
%systemd_postun_with_restart phc2sys.service ptp4l.service timemaster.service

%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/linuxptp.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

%postun selinux
if [ $1 -eq 0 ]; then
	%selinux_modules_uninstall -s %{selinuxtype} linuxptp
	%selinux_relabel_post -s %{selinuxtype}
fi

%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/linuxptp.pp.*
%{_datadir}/selinux/devel/include/distributed/linuxptp.if
%ghost %verify(not md5 size mtime) %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/linuxptp

%files
%license COPYING
%doc README.org configs
%{_sbindir}/hwstamp_ctl
%{_sbindir}/nsm
%{_sbindir}/phc2sys
%{_sbindir}/phc_ctl
%{_sbindir}/pmc
%{_sbindir}/ptp4l
%{_sbindir}/timemaster
%{_sbindir}/ts2phc
%config(noreplace) %{_sysconfdir}/ptp4l.conf
%config(noreplace) %{_sysconfdir}/sysconfig/phc2sys
%config(noreplace) %{_sysconfdir}/sysconfig/ptp4l
%config(noreplace) %{_sysconfdir}/timemaster.conf
%{_unitdir}/phc2sys.service
%{_unitdir}/ptp4l.service
%{_unitdir}/timemaster.service
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.1-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 13 2023 cunshunxia <cunshunxia@tencent.com> - 3.1.1-1
- initial build
